@@ -20,7 +20,7 @@ def bollinger_bands(dataframe: DataFrame, period: int = 21, stdv: int = 2,
         <column_prefix>_lower, <column_prefix>_middle, and <column_prefix>_upper,
     """
     rolling_mean = dataframe[field].rolling(window=period).mean()
-    rolling_std = dataframe[field].rolling(window=period).std()
+    rolling_std = dataframe[field].rolling(window=period).std(ddof=0)
     dataframe[f"{colum_prefix}_lower"] = rolling_mean - (rolling_std * stdv)
     dataframe[f"{colum_prefix}_middle"] = rolling_mean
     dataframe[f"{colum_prefix}_upper"] = rolling_mean + (rolling_std * stdv)
@@ -68,7 +68,8 @@ def tema(dataframe, period, field='close'):
 
 # Other Overlap Studies Functions
 def hull_moving_average(dataframe, period, field='close') -> ndarray:
-    from pyti.hull_moving_average import hull_moving_average as hma
+    # TODO: Remove this helper method, it's a 1:1 call to qtpylib's HMA.
+    from technical.qtpylib import hma
     return hma(dataframe[field], period)
 
 
